package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`/@`!````V"%```````!``````````*#3````
M`````````$``.``)`$``'``;``8````%````0`````````!``$```````$``
M0```````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"0```````.`)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````/2^````````]+X`````````
M`"````````$````&````\,T```````#PS6```````/#-8```````:`0`````
M``#X%```````````(````````@````8````(S@````````C.8```````",Y@
M``````#P`0```````/`!````````"``````````$````!````%0"````````
M5`)```````!4`D```````$0`````````1``````````$`````````%#E=&0$
M````B+@```````"(N$```````(BX0```````]`````````#T``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"`````````!2Y71D!````/#-````````\,U@``````#PS6``
M`````!`"````````$`(````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````&`````0`
M```4`````P```$=.50!BQZ4T[.:[/4%F!@6Y=+UF)/\T=24```!%````!```
M``@````@'!``!4`$ABH"0`"0A@&HPBD`($D@!`NXHCA-N@0&"D4```!&````
M````````````````2````$H```!+`````````$P```!-````3P```%````!1
M````4@````````!4``````````````!5````5@```%D``````````````%H`
M``!<````70```%\`````````80```&,``````````````&4```!F````9P``
M``````#)U;)QSMY'+:/@^TGJT^\.I]VC:R_%F[;;S>.>A_F<@5:DFY9K"4/6
M.?*+'`TZEPO%B060#!3BGHD'<-,A_^0."XH05VI_FGRR`8MOQ;F<0'^IG)MN
MQ=\?V7%8'+OCDGRL2^/`U634?."G`@HS8MOM>O!*:V>OS&9"1=7LXT?&`7U!
MCL7#Y3\L\MO3'?JA;&"YC?$.````````````````````````````````/0$`
M`!(`````````````````````````(0(``!(`````````````````````````
MH`(``!(`````````````````````````=0(``!(`````````````````````
M````$0```"``````````````````````````IP(``!(`````````````````
M````````,P,``!(`````````````````````````TP```!(`````````````
M````````````O`(``!(`````````````````````````&P,``!(`````````
M````````````````$P,``!(`````````````````````````KP```!(`````
M````````````````````[`,``!(`````````````````````````.`$``!(`
M````````````````````````WP(``!(`````````````````````````R@(`
M`!(`````````````````````````CP(``!(`````````````````````````
M+`,``!(`````````````````````````4`,``!(`````````````````````
M````H0$``!(`````````````````````````80$``!(`````````````````
M````````T0(``!(`````````````````````````X0```!(`````````````
M````````````ZP$``!(`````````````````````````3@(``!(`````````
M````````````````A@(``!(`````````````````````````B`$``!(`````
M````````````````````7@(``!(`````````````````````````?0(``!(`
M````````````````````````V`$``!(`````````````````````````M0(`
M`!(`````````````````````````'`(``!(`````````````````````````
MA0,``!(`````````````````````````?@,``!(`````````````````````
M````;P$``!(`````````````````````````0P,``!(`````````````````
M````````+0```"``````````````````````````\P(``!(`````````````
M````````````>````!(`````````````````````````#P$``!(`````````
M````````````````.@(``!(`````````````````````````Y`$``!(`````
M````````````````````O@```!(`````````````````````````E@$``!(`
M````````````````````````:@```!(`````````````````````````0@$`
M`!(`````````````````````````^@(``!(`````````````````````````
MS0$``!(`````````````````````````'`$``!(`````````````````````
M````K0(``!(`````````````````````````%0(``!(`````````````````
M````````;P,``!(`````````````````````````5P,``!(`````````````
M````````````KP$``!(`````````````````````````=P,``!(`````````
M````````````````PP(``!(`````````````````````````/````"``````
M````````````````````\P```!(`````````````````````````/`,``!(`
M````````````````````````?P$``!(`````````````````````````"`,`
M`!(`````````````````````````<`(``!(`````````````````````````
M,@(``!(`````````````````````````Y0(``!(`````````````````````
M````AP```!(`````````````````````````4````"``````````````````
M````````V`(``!(`````````````````````````80,``!(`````````````
M````````````3@$``!(```!`'D``````````````````&@0``!(`#0"@2$``
M`````'X+````````<P0``!(`#0`014```````-L!````````PP,``!(`#@!T
M64``````````````````F0,``"$`&0!PTF````````@`````````R0,``!(`
M#0!00D````````4`````````600``!(`#0#@6$```````(D`````````G@``
M`!(```#P'D``````````````````+0$``!$`&0!@TF````````0`````````
M)P0``!``&``XTF``````````````````)0,``!$`&0"8TF````````@`````
M````*00``"``&``XTF``````````````````F`,``"$`&0!PTF````````@`
M````````N0,``!(`#0!P64````````(`````````:00``!$`&`!0TF``````
M``@`````````B`0``!(`#0!@0D```````+,!`````````@$``!$`&0!HTF``
M``````$`````````D@,``!(`#0#`'T```````!@"````````IP0``!(`#0#P
M1D```````%0`````````EP,``!$`&0!PTF````````@`````````V@,``!(`
M#0!01T```````"0`````````]0,``!(`#0`06$```````&\`````````J`,`
M`!``&0!8TF``````````````````M`,``!``&0#HXF``````````````````
M-`0``!$`#P"`64````````0`````````T00``!(`#0`@5$```````.,#````
M````0P0``!(`#0"004```````+D`````````+00``!(`#0#8(4``````````
M````````O0$``!(`````'$``````````````````#@0``!(`#0!01$``````
M`+\`````````H0,``!``&`!8TF```````````````````00``!(`#0`@1$``
M`````"0`````````M00``!(`#0"`6$```````#H`````````@`0``!(`#0`0
M04```````"H`````````]@$``!$`&0"`TF```````!,`````````E00``!(`
M#0"`1T```````!\!````````@@0``!(`"P!(&T```````````````````&QI
M8G!E<FPN<V\N-2XQ-`!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G
M;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R
M;%]S879E7V1E<W1R=6-T;W)?>`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N
M<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R
M;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E
M<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F
M<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E
M='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N,`!O<&5N-C0`<F5A
M9`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<'1H<F5A9%]G971S<&5C:69I
M8P!C;&]S90!L:6)C+G-O+C8`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N
M8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK
M`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')T;VL`<W1R;&5N`&UE
M;7-E=`!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N
M8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G
M971U:60`<F5A9&QI;FL`97AE8W9P`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A
M9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?
M;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?961A=&$`7U]B<W-?<W1A<G0`
M7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA;64`
M<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D
M:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET
M`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`
M<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?
M4$%27T-,14%24U1!0TL`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N
M,BXU`$=,24)#7S(N,30`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?
M,BXT`````@`#``(``@````(``@````(``@`"`````@````(``@`$``(``@``
M`````@```````P`"````!0`"`````@`#``(``@````8````'```````#``(`
M```````````&```````"``,``@`"`````@`"```````"`````@`"``,`!@``
M`````@`&`````0`!``$``@`!``$```````$``@`!``(``0`!``$````!``$`
M`@`!``$``0`!``$``0`!``$````!``$``0`!``$````!``$```````$``0`%
M`@``$````"````!U&FD)```#`.<$`````````0`%`%0"```0`````````)21
ME@8```<`\P0``!````!T&6D)```&`/X$```0````<AEI"0``!0`*!0``$```
M`!1I:0T```0`%@4``!````!U&FD)```"`.<$````````^,]@```````&````
M)0``````````````8-)@```````%````30``````````````:-)@```````%
M````50``````````````<-)@```````%````6```````````````@-)@````
M```%````9P``````````````F-)@```````%````3P``````````````&-!@
M```````'`````0``````````````(-!@```````'`````@``````````````
M*-!@```````'`````P``````````````,-!@```````'````!```````````
M````.-!@```````'````!@``````````````0-!@```````'````!P``````
M````````2-!@```````'````"```````````````4-!@```````'````"0``
M````````````6-!@```````'````80``````````````8-!@```````'````
M"@``````````````:-!@```````'````"P``````````````<-!@```````'
M````#```````````````>-!@```````'````#0``````````````@-!@````
M```'````#@``````````````B-!@```````'````#P``````````````D-!@
M```````'````$```````````````F-!@```````'````$0``````````````
MH-!@```````'````$@``````````````J-!@```````'````$P``````````
M````L-!@```````'````%```````````````N-!@```````'````%0``````
M````````P-!@```````'````%@``````````````R-!@```````'````%P``
M````````````T-!@```````'````&```````````````V-!@```````'````
M&0``````````````X-!@```````'````&@``````````````Z-!@```````'
M````&P``````````````\-!@```````'````'```````````````^-!@````
M```'````'0```````````````-%@```````'````'@``````````````"-%@
M```````'````'P``````````````$-%@```````'````(```````````````
M&-%@```````'````(0``````````````(-%@```````'````(@``````````
M````*-%@```````'````(P``````````````,-%@```````'````)```````
M````````.-%@```````'````)0``````````````0-%@```````'````)@``
M````````````2-%@```````'````)P``````````````4-%@```````'````
M*```````````````6-%@```````'````*0``````````````8-%@```````'
M````*@``````````````:-%@```````'````*P``````````````<-%@````
M```'````+```````````````>-%@```````'````10``````````````@-%@
M```````'````+0``````````````B-%@```````'````+@``````````````
MD-%@```````'````+P``````````````F-%@```````'````,```````````
M````H-%@```````'````,0``````````````J-%@```````'````,@``````
M````````L-%@```````'````,P``````````````N-%@```````'````-```
M````````````P-%@```````'````-0``````````````R-%@```````'````
M-@``````````````T-%@```````'````3```````````````V-%@```````'
M````-P``````````````X-%@```````'````.```````````````Z-%@````
M```'````.@``````````````\-%@```````'````.P``````````````^-%@
M```````'````/````````````````-)@```````'````/0``````````````
M"-)@```````'````/@``````````````$-)@```````'````/P``````````
M````&-)@```````'````0```````````````(-)@```````'````00``````
M````````*-)@```````'````0P``````````````,-)@```````'````1```
M````````````2(/L"$B+!:6T(`!(A<!T!>AC`@``2(/$",,`````````````
M`````/\UDK0@`/\EE+0@``\?0`#_)9*T(`!H`````.G@_____R6*M"``:`$`
M``#IT/____\E@K0@`&@"````Z<#_____)7JT(`!H`P```.FP_____R5RM"``
M:`0```#IH/____\E:K0@`&@%````Z9#_____)6*T(`!H!@```.F`_____R5:
MM"``:`<```#I</____\E4K0@`&@(````Z6#_____)4JT(`!H"0```.E0____
M_R5"M"``:`H```#I0/____\E.K0@`&@+````Z3#_____)3*T(`!H#````.D@
M_____R4JM"``:`T```#I$/____\E(K0@`&@.````Z0#_____)1JT(`!H#P``
M`.GP_O___R42M"``:!````#IX/[___\E"K0@`&@1````Z=#^____)0*T(`!H
M$@```.G`_O___R7ZLR``:!,```#IL/[___\E\K,@`&@4````Z:#^____)>JS
M(`!H%0```.F0_O___R7BLR``:!8```#I@/[___\EVK,@`&@7````Z7#^____
M)=*S(`!H&````.E@_O___R7*LR``:!D```#I4/[___\EPK,@`&@:````Z4#^
M____);JS(`!H&P```.DP_O___R6RLR``:!P```#I(/[___\EJK,@`&@=````
MZ1#^____):*S(`!H'@```.D`_O___R6:LR``:!\```#I\/W___\EDK,@`&@@
M````Z>#]____)8JS(`!H(0```.G0_?___R6"LR``:"(```#IP/W___\E>K,@
M`&@C````Z;#]____)7*S(`!H)````.F@_?___R5JLR``:"4```#ID/W___\E
M8K,@`&@F````Z8#]____)5JS(`!H)P```.EP_?___R52LR``:"@```#I8/W_
M__\E2K,@`&@I````Z5#]____)4*S(`!H*@```.E`_?___R4ZLR``:"L```#I
M,/W___\E,K,@`&@L````Z2#]____)2JS(`!H+0```.D0_?___R4BLR``:"X`
M``#I`/W___\E&K,@`&@O````Z?#\____)1*S(`!H,````.G@_/___R4*LR``
M:#$```#IT/S___\E`K,@`&@R````Z<#\____)?JR(`!H,P```.FP_/___R7R
MLB``:#0```#IH/S___\EZK(@`&@U````Z9#\____)>*R(`!H-@```.F`_/__
M_R7:LB``:#<```#I</S___\ETK(@`&@X````Z6#\____)<JR(`!H.0```.E0
M_/___R7"LB``:#H```#I0/S___\ENK(@`&@[````Z3#\____);*R(`!H/```
M`.D@_/___R6JLB``:#T```#I$/S___\EHK(@`&@^````Z0#\____)9JR(`!H
M/P```.GP^____R62LB``:$````#IX/O___\EBK(@`&A!````Z=#[____)8*R
M(`!H0@```.G`^____R5ZLB``:$,```#IL/O__U-(@^PPB7PD'$B)="002(U\
M)!Q(B50D"$B-="002(U4)`CH^?W__[I`'D``O_`>0`!(B=;HQS@``(`]:+(@
M``!U+^CI_/__2(7`2(D%S\(@``^$I@$``$B)Q^@1_/__BST[LB``Z-;]___&
M@,P$````BSTILB``Z,3]__^`B#L%```"BST7LB``Z++]__^`B#L%```!BT0D
M'(UX!4AC_TB%_P^(&`$``/)(#RK'\@]8!0.8``!F#RX%`Y@```^'1`$``$C!
MYP/HQ/S__TB+3"002(D%,,(@`,<%+L(@``0```!(BQ%(QT`(:5M``$C'0!AL
M6T``2(D02(L5D;$@`$B)4!"+5"0<@_H!?B>-<OY,C03U"````#'V#Q^`````
M`$B+?#$(2(E\,"!(@\8(3#G&=>V-2@1(BSWCP2``@\(#13'`OD!!0`!(8\E(
MQT3(^`````!(B<'H9/W__X7`B<-T.TB+/;?!(`#H@OO__TB-="0L,<"_+5I`
M`.B!&```2(7`="E(BSV5P2``Z`#[___H^_S__TB#Q#")V%O#2(L]?,$@`.C7
M_?__B</KM4B+/63!(`!(A?]T).B2-@``Z\1(B?A(B?I(T>B#X@%("=#R2`\J
MP/(/6,#IT/[__TB-="0LO^)90`#H%!@``$B%P$B)!2+!(`!TC$B)Q^N\OP$`
M``#HF?W__[Z`TF``O]U90``QP.A(_/__,>U)B=%>2(GB2(/D\%!42<?`<%E`
M`$C'P>!80`!(Q\?`'T``Z'_[___T9I!F+@\?A```````9I"X7])@`%5(+5C2
M8`!(@_@.2(GE=P)=P[@`````2(7`=/1=OUC28`#_X`\?@`````"X6-)@`%5(
M+5C28`!(P?@#2(GE2(G"2,'J/T@!T$C1^'4"7<.Z`````$B%TG3T74B)QK]8
MTF``_^(/'X``````@#T9L"```'4154B)Y>A^____7<8%!K`@``'SPP\?0`!(
M@SU8JR```'0>N`````!(A<!T%%6_`,Y@`$B)Y?_07>E[____#Q\`Z7/___\/
M'P!!5TR-1S@QR4%6055!5%532('L$`(``&8/'X0``````$F+%`A(B=!(B=9(
MP>`(2,'F&"4``/\`B?9("?!(B=9(P>X(@>8`_P``2`GP2(G62,'N&$`/MO9(
M"?!(B=9(P>X@2(E$3(A(B?!(P>882,'@"(GV)0``_P!("?!(B=9(P>HX2,'N
M*('F`/\``$@)\$@)T$B)1$R02(/!"$B#^4`/A7O___](C40DB$B-M"3P`0``
M2(U0:&8N#Q^$``````!(BT+82#,"2(/""$@S0J!(,T*02(G!2`'`2,'I'T@)
MP8/A_TB)2A!(.?)UU$B+%TR+;R!,BT\(3(M7$$R+9QA,B>E(B=!(`TPDB$B)
MUDC!Z!M,B<U(P>8%2,'M`DV)X$@)\$P#1"202(G6B<!(]]9)B=9,C9P!F7F"
M6DR)R$R)T4CWT$PAR4PAUDPAX$G![@),B=-("<A(`UPDF$D!PTR)R$C!X!Y$
MB=E("<6)[4B)Z$@AT$@)\$B)SDV-A`"9>8):2(G(2,'N&TC!X`5("<9(B=!(
MP>`>B?9)"<9(B<A)`?!%B?9(]]!$B<9-(?-((>A,"=A,C9P#F7F"6DB)\$B)
M\TC!XP5(P>@;2`G82(G+2,'A'HG`2,'K`DD!PT@)RT@#;"2@2(GQB=M$B=A(
M]]%)(=A,(?%,`W0DJ$P)P4R-A`V9>8):2(G!2(G%2,'E!4C!Z1M(">E(B?5(
MP>8>2,'M`HG)2`GU2(G&20'(B>U(]]9$B<%((=Y)(>M(`UPDL$P)WDV-G#:9
M>8):2(G.28G.2<'F!4C![AM,"?9)B<9(P>`>2<'N`HGV20G&2(G(20'S18GV
M2/?01(G>32'P2"'H3`G`3(V$`YEY@EI(B?!(B?-(P>,%2,'H&T@)V$B)RTC!
MX1Z)P$C!ZP))`<!("<M(`VPDN$B)\8G;1(G`2/?122';3"'Q3`-T),!,"=E,
MC9P-F7F"6DB)P4B)Q4C!Y05(P>D;2`GI2(GU2,'F'DC![0*)R4@)]4B)QDD!
MRXGM2/?61(G92"'>22'H2`-<),A,"<9-C80VF7F"6DB)SDF)SDG!Y@5(P>X;
M3`GV28G&2,'@'DG![@*)]DD)QDB)R$D!\$6)]DCWT$2)QDTA\T@AZ$P)V$R-
MG`.9>8):2(GP2(GS2,'C!4C!Z!M("=A(B<M(P>$>B<!(P>L"20'#2`G+2`-L
M)-!(B?&)VT2)V$CWT4DAV$PA\4P#="383`G!3(V$#9EY@EI(B<%(B<5(P>4%
M2,'I&T@)Z4B)]4C!YAY(P>T"B<E("?5(B<9)`<B)[4CWUD2)P4@AWDDAZT@#
M7"3@3`G>38V<-IEY@EI(B<Y)B<Y)P>8%2,'N&TP)]DF)QDC!X!Y)P>X"B?9)
M"<9(B<A)`?-%B?9(]]!$B=Y-(?!((>A,"<!,C80#F7F"6DB)\$B)\TC!XP5(
MP>@;2`G82(G+2,'A'HG`2,'K`DD!P$@)RT@#;"3H2(GQB=M$B<!(]]%)(=M,
M(?%,`W0D\$P)V4R-G`V9>8):2(G!2(G%2,'E!4C!Z1M(">E(B?5(P>8>2,'M
M`HG)2`GU2(G&20'+B>U(]]9$B=E((=Y)(>A(`UPD^$P)QDV-A#:9>8):2(G.
M28G.2<'F!4C![AM,"?9)B<9(P>`>2<'N`HGV20G&2(G(20'P18GV2/?01(G&
M32'S2"'H3`G828GS2(V<`YEY@EI(B?!)P>,%2,'H&TP)V$F)RTC!X1Z)P$G!
MZP)(`<-)"<M(`RPD2(GQ18G;B=A(]]%-(=A,(?%,`W0D"$P)P4R-A`V9>8):
M2(G!2(G%2,'E!4C!Z1M(">E(B?5(P>8>2,'M`HG)2`GU2(G&20'(B>U(]]9$
MB<%,(=Y((>M,`UPD$$@)WDF-G#:9>8):2(G.28G.2<'F!4C![AM,"?9)B<9(
MP>`>2<'N`HGV20G&2(G(2`'S18GV2/?0B=Y-(?!((>A,"<!-C80#F7F"6DB)
M\$F)\TG!XP5(P>@;3`G828G+2,'A'HG`2<'K`DD!P$D)RT@#;"082(GQ18G;
M1(G`2/?13"';3"'Q3`-T)"!("=E(B<-(C:P-F7F"6DB)P4C!XP5(P>D;2`G9
MB<E(`<U(B?%(P>8>2,'I`HGK2`GQ2(G&08G/2/?632'X3"'>3`-<)"A,"<9)
MB=A,`WPD,$V-M#:9>8):2(G>2<'@!4C![AM,"<:)]DD!]DB)QDC!X!Y(P>X"
M18GP2`G&3(G`2#'Q2,'H&S'-3(G!2,'A!4F-K"NAZ]EN2`G(2(G92,'C'DC!
MZ0*)P$@)V4@!Q4B)R$&)ZT@Q\$R)VXGV03'&3(G82,'C!4C!Z!M/C;0WH>O9
M;D@#="0X2`G8B<!)`<9,B<!)P>`>2,'H`D2)\TP)P$F)P$DQR(G)2`-,)$!$
M,<5)B=A(C:PNH>O9;DB)WDG!X`5(P>X;3`G&B?9(`?5,B=Y)P>,>2,'N`D&)
MZ$P)WDF)\TDQPXG`2`-$)$A%,=Y-B<-.C;0QH>O9;DR)P4G!XP5(P>D;3`G9
MB<E)`<Y(B=E(P>,>2,'I`D6)\T@)V4B)RT@Q\XGV,=U,B=M(C:PHH>O9;DR)
MV$C!Z!M(P>,%2`-T)%!("=B)P$@!Q4R)P$G!X!Y(P>@"B>M,"<!)B<!),<B)
MR4@#3"1813'&28G83HVT-J'KV6Y(B=Y)P>`%2,'N&TP)QHGV20'V3(G>2<'C
M'DC![@)%B?!,"=Y)B?-),<.)P$@#1"1@1#'=38G#2(VL*:'KV6Y,B<%)P>,%
M2,'I&TP)V8G)2`'-2(G92,'C'DC!Z0)!B>M("=E(B<M(,?.)]D$QWDR)VTZ-
MM#"AZ]EN3(G82,'C!4C!Z!M("=B)P$D!QDR)P$C!Z`))P>`>2`-T)&A,"<!$
MB?-)B<!),<B)R4@#3"1P1#'%28G82(VL+J'KV6Y(B=Y)P>`%2,'N&TP)QHGV
M2`'U3(G>2<'C'DC![@)!B>A,"=Y)B?-),<.)P$@#1"1X13'>38G#3HVT,:'K
MV6Y,B<%)P>,%2,'I&TP)V8G)20'.2(G92,'C'DC!Z0)%B?-("=E(B<M(,?.)
M]C'=3(G;2(VL**'KV6Y,B=A(P>,%2,'H&T@)V(G`2`'%3(G`2<'@'DC!Z`*)
MZTP)P$@#M"2`````28G`23'(B<E(`XPDB````$4QQDF)V$Z-M#:AZ]EN2(G>
M2<'@!4C![AM,"<:)]DD!]DR)WDG!XQY(P>X"18GP3`G>28GS23'#B<!(`X0D
MD````$0QW4V)PTB-K"FAZ]EN3(G!2<'C!4C!Z1M,"=F)R4@!S4B)V4C!XQY(
MP>D"08GK2`G92(G+2#'SB?9(`[0DF````$$QWDR)VTZ-M#"AZ]EN3(G82,'C
M!4C!Z!M("=B)P$D!QDR)P$G!X!Y(P>@"1(GS3`G`28G`23'(B<E$,<5)B=A(
MC:PNH>O9;DB)WDC![AM)P>`%2`.,)*````!,"<:)]D@!]4R)WDG!XQY(P>X"
M08GH3`G>28GS23'#B<!(`X0DJ````$4QWDV)PTZ-M#&AZ]EN3(G!2<'C!4C!
MZ1M,"=F)R4D!SDB)V4C!XQY(P>D"18GS2`G92(G+2#'SB?9(`[0DL````#'=
M3(G;2(VL**'KV6Y,B=A(P>,%2,'H&T@)V(G`2`'%3(G`2<'@'DC!Z`*)ZTP)
MP$F)P$DQR(G)13'&28G83HV\-J'KV6Y(B=Y)P>`%2,'N&TP)QDV)V(GV20'W
M2<'C'DG!Z`)-"=A(`XPDN````$6)_DR)QD@QQHG`2`.$),`````Q]4R)]DR-
MG"FAZ]EN3(GQ2,'F!4C!Z1M("?%(B=Y(P>,>2,'N`HG)2`G>20'+2(GQ1(G=
M3#'!18G`03'/2(GI3HV\.*'KV6Y(B>A(P>$%2,'H&T@)R$R)\4G!YAZ)P$C!
MZ0))`<>XW+P;CTP)\4F)QDP#M"3(````1(G[30'P28G.20GV32'S28G.22'V
MB?9%"?-/C30828G828G;2<'C!4G!Z!M-"=A%B<!-`<9)B>A(P>4>2<'H`D6)
M\TD)Z$B)Q4@#K"30````2`'N3(G%2`G-22'O3(G%2"'-B<E!">],B=U)`?=,
MB=Y(P>4%2,'N&T@)[HGV20'W2(G>2,'C'DC![@)$B?U("=Y(B<-(`YPDV```
M`$@!V4B)\TP)PTDAWDB)\TPAPT6)P$$)WDB)ZTD!SDB)Z4C!XP5(P>D;2`G9
MB<E)`<Y,B=E)P>,>2,'I`D2)\TP)V4F)PTP#G"3@````30'828G+20GS32'?
M28G+22'SB?9%"=])B=M-`<=)B=A)P>,%2<'H&TT)V$6)P$T!QTF)Z$C!Y1Y)
MP>@"18G[20GH2(G%2`.L).@```!(`>Y,B<5("<U)(>Y,B<5((<V)R4$)[DR)
MW4D!]DR)WDC!Y05(P>X;2`GNB?9)`?9(B=Y(P>,>2,'N`D2)]4@)WDB)PT@#
MG"3P````2`'92(GS3`G#22'?2(GS3"'#18G`00G?2(GK20'/2(GI2,'C!4C!
MZ1M("=F)R4D!STR)V4G!XQY(P>D"1(G[3`G928G#3`.<)/@```!-`=A)B<M)
M"?--(=Y)B<M)(?.)]D4)WDF)VTT!QDF)V$G!XP5)P>@;30G818G`30'&28GH
M2,'E'DG!Z`)%B?-)">A(B<5(`ZPD``$``$@![DR)Q4@)S4DA[TR)Q4@AS8G)
M00GO3(G=20'W3(G>2,'E!4C![AM(">Z)]DD!]TB)WDC![@)(P>,>1(G]2`G>
M2(G#2`.<)`@!``!(`=E(B?-,"<-)(=Y(B?-,(<-%B<!!"=Y(B>M)`<Y(B>E(
MP>,%2,'I&T@)V8G)20'.3(G92<'C'DC!Z0)$B?-,"=E)B<-,`YPD$`$``$T!
MV$F)RTD)\TTAWTF)RTDA\XGV10G?28G;30''28G82<'C!4G!Z!M-"=A%B<!-
M`<=)B>A(P>4>2<'H`D6)^TD)Z$B)Q4@#K"08`0``2`'N3(G%2`G-22'N3(G%
M2"'-B<E!">Y,B=U)`?9,B=Y(P>4%2,'N&T@)[HGV20'V2(G>2,'C'DC![@)$
MB?5("=Y(B<-(`YPD(`$``$@!V4B)\TP)PTDAWTB)\TPAPT6)P$$)WTB)ZTD!
MSTB)Z4C!XP5(P>D;2`G9B<E)`<],B=E)P>,>2,'I`D2)^TP)V4F)PTP#G"0H
M`0``30'828G+20GS32'>28G+22'SB?9%"=Y)B=M-`<9)B=A)P>@;2<'C!4T)
MV$6)P$T!QDF)Z$C!Y1Y)P>@"18GS20GH2(G%2`.L)#`!``!(`>Y,B<5("<U)
M(>],B<5((<V)R4$)[TR)W4D!]TR)WDC!Y05(P>X;2`GNB?9)`?=(B=Y(P>,>
M2,'N`D2)_4@)WDB)PT@#G"0X`0``2`'92(GS3`G#22'>2(GS3"'#18G`00G>
M2(GK20'.2(GI2,'C!4C!Z1M("=F)R4D!SDR)V4C!Z0))P>,>1(GS3`G928G#
M3`.<)$`!``!-`=A)B<M)"?--(=])B<M)(?.)]D4)WTF)VTT!QTF)V$G!XP5)
MP>@;30G818G`30''28GH2,'E'DG!Z`)%B?M)">A(B<5(`ZPD2`$``$@![DR)
MQ4@)S4DA[DR)Q4@AS8G)00GN3(G=20'V3(G>2,'E!4C![AM(">Z)]DD!]DB)
MWDC!XQY(P>X"1(GU2`G>2(G#2`.<)%`!``!(`=E(B?-,"<-)(=](B?-,(<-%
MB<!!"=](B>M)`<](B>E(P>,%2,'I&T@)V8G)20'/3(G92<'C'DC!Z0)$B?M,
M"=E)B<-,`YPD6`$``$@#A"1@`0``30'828G+20GS32'>28G+22'SB?9%"=Y)
MB=M(`?!-`<9)B=A)P>,%2<'H&TT)V$6)P$T!QDF)Z$C!Y1Y)P>@"18GS20GH
M3(G&2`G.22'W3(G&2"'.B<E!"?=,B=Y)`<=,B=A(P>@;2,'F!4@)\$B)WDC!
MXQZ)P$C![@))`<>XUL%BRD@)WDB)PT@#G"1H`0``1(G]2`'92(GS3#'#18G`
M03'>2(GK20'.2(GI2,'C!4C!Z1M("=F)R4D!SDR)V4G!XQY(P>D"1(GS3`G9
M28G#3`.<)'`!``!-`=A)B<M),?.)]D4QWTF)VTT!QTF)V$G!XP5)P>@;30G8
M18G`30''28GH2,'E'DG!Z`)%B?M)">A(B<5(`ZPD>`$``$@![DR)Q4@QS8G)
M03'N3(G=20'V3(G>2,'E!4C![AM(">Z)]DD!]DB)WDC!XQY(P>X"1(GU2`G>
M2(G#2`.<)(`!``!(`=E(B?-,,<-%B<!!,=](B>M)`<](B>E(P>,%2,'I&T@)
MV8G)20'/3(G92<'C'DC!Z0)$B?M,"=E)B<-,`YPDB`$``$T!V$F)RTDQ\XGV
M13'>28G;30'&28G82<'C!4G!Z!M-"=A%B<!-`<9)B>A(P>4>2<'H`D6)\TD)
MZ$B)Q4@#K"20`0``2`'N3(G%2#'-B<E!,>],B=U)`?=,B=Y(P>4%2,'N&T@)
M[HGV20'W2(G>2,'C'DC![@)$B?U("=Y(B<-(`YPDF`$``$@!V4B)\TPQPT6)
MP$$QWDB)ZTD!SDB)Z4C!XP5(P>D;2`G9B<E)`<Y,B=E)P>,>2,'I`D2)\TP)
MV4F)PTP#G"2@`0``30'828G+23'SB?9%,=])B=M-`<=)B=A)P>,%2<'H&TT)
MV$6)P$T!QTF)Z$G!Z`)(P>4>18G[20GH2(G%2`.L)*@!``!(`>Y,B<5(,<V)
MR4$Q[DR)W4D!]DR)WDC!Y05(P>X;2`GNB?9)`?9(B=Y(P>,>2,'N`D2)]4@)
MWDB)PT@#G"2P`0``2`'92(GS3#'#18G`03'?2(GK20'/2(GI2,'C!4C!Z1M(
M"=F)R4D!STR)V4G!XQY(P>D"1(G[3`G928G#3`.<)+@!``!-`=A)B<M),?.)
M]D4QWDF)VTT!QDF)V$G!Z!M)P>,%30G818G`30'&28GH2,'E'DG!Z`)%B?-)
M">A(B<5(`ZPDP`$``$@![DR)Q4@QS8G)03'O3(G=20'W3(G>2,'E!4C![AM(
M">Z)]DD!]TB)WDC!XQY(P>X"1(G]2`G>2(G#2`.<),@!``!(`=E(B?-,,<-%
MB<!!,=Y(B>M)`<Y(B>E(P>,%2,'I&T@)V8G)20'.3(G92<'C'DC!Z0)$B?-,
M"=E)B<-,`YPDT`$``$T!V$F)RTDQ\XGV13'?28G;30''28G82<'C!4G!Z!M-
M"=A%B<!-`<=)B>A(P>4>2<'H`D6)^TD)Z$B)Q4@#K"38`0``2`'N3(G%2#'-
MB<E!,>Y,B=U)`?9,B=Y(P>4%2,'N&T@)[HGV20'V2(G>2,'C'DC![@)$B?5(
M"=Y(B<-(`YPDX`$``$@!V4B)\TPQPT6)P$$QWTB)ZTD!STB)Z4C!XP5(P>D;
M2`G9B<E)`<],B=E)P>,>2,'I`D2)^TP)V4F)PTP#G"3H`0``30'828G+23'S
MB?9%,=Y)B=M-`<9)B=A)P>,%2<'H&TT)V$6)P$T!QDF)Z$C!Y1Y)P>@"18GS
M20GH2(G%2`.L)/`!``!(`>Y,B<5(,<V)R4$Q[TR)W4D!]TR)WDC!Y05(P>X;
M2`GNB?9)`?=(B=Y(P>,>2,'N`D2)_4@)WDB)PT@#G"3X`0``2`'92(GS3#'#
M18G`03'>2HT<,4B)Z4F)[DG!Y@5(P>D;3`GQ`<M,B=E(P>D"2<'C'D@#A"0`
M`@``3`G928GK2,'E'DG!ZP)!`=E)">M(B=U,`<!)B<A(P>4%23'P1`'A1`'N
M13''10':3HT$.$B)V$C!Z!M(">A$`<`!PDB)%TR)3PA,B5<02(E/&$B)=R!(
M@<00`@``6UU!7$%=05Y!7\,/'X``````05=!5D%528G]05154TB#[`A(A?]T
M:$R+-9.8(`!-A?9T7`^V!TF)]SP]=&2$P'1@28G\28/$`4$/M@0D/#UT!(3`
M=>]%*>Q)BQY(A=MT+TUCY$R)]0\?`$R)XDR)[DB)W^B*X?__A<!U!T*`/",]
M="=(@\4(2(M=`$B%VW7:2(/$"#'`6UU!7$%=05Y!7\.013'DZ[(/'P!,*?5*
MC40C`4C!_0-!B2](@\0(6UU!7$%=05Y!7\-F+@\?A```````4TB)^TB#[!`/
M'X0``````$B-="0,,<!(B=_H(?___TB%P'0N2&-4)`Q(BP7`ER``2(T$T$B+
M4`A(A=)(B1!TT$B#P`A(BU`(2(722(D0=?#KODB#Q!!;PP\?A```````05<Q
MP$%6055!5$F)_%532(GS2(/L&(`^/0^4P$@!PTB)W^AIX?__2(UT)`Q)B<5,
MB><QP.BG_O__2(7`2(G%#X3[````2(G'Z$/A__]$B>I(.=`/@\\```"+;"0,
M00^V!"0\/0^$A@$``(3`#X1^`0``3(GBZPUF#Q^$``````"$R70,2(/"`0^V
M"H#Y/77P1"GB2(L%]I8@`$*-?"H"2(TLZ.B(XO__2(7`2(E%``^$3@$``(M4
M)`Q(BP70EB``28U,)`%(BQ3000^V!"2$P(@"=1[K(&8N#Q^$``````!(@\$!
M#[9!_TB#P@&$P(@"=`0\/77JQ@(],<`/'T0```^V#`.(3`(!2(/``83)=?`Q
MP$B#Q!A;74%<05U!7D%?PP\?@`````!(@\,!#[9#_TB#Q0&$P(A%_W7MZ],/
M'P!,BS5)EB``28,^``^$I@```$R)\#'M9BX/'X0``````$B#P`B#Q0%(@S@`
M=?.-=0)(8_9(P>8#BP5CIB``A<!T+TR)]^@WXO__2(7`2(D%_94@`'1N3&/]
M2(G!2L=$^0@`````B6PD#.FP_O__#Q\`2(GWQP4CIB```0```.ANX?__2(7`
M=#Q,8_U,B?9(B<=*C13]`````.@#XO__2(G!2(D%J94@`.NR#Q^``````#'2
MZ9S^__^^$````#'MZ73___^X_____^D%____#Q\`055!5%5(B?U32('LF```
M`$B%_W0%@#\`=19(@<28````6UU!7$%=PP\?A```````Z/O>__](A<!)B<1T
MW4R)Y^B;X?__2(7`2(G##X2?````@'L3+@^$M0```$B#PQ-(B>_H&=___TB)
MWTF)Q>@.W___08U\!0)(8__HH>#__TF)V4F)Q4B)QTF)Z+F$64``2,?"____
M_[X!````,<#H'>+__[\!````2(GB3(GNZ&W>__^#^/],B>]T$(M$)!@E`/``
M`#T`0```=&WHX-W__TR)[^BXW?__3(GGZ`#A__](A<!(B<,/A67___\/'T``
M3(GGZ"C?__](B>_H<-[__TB!Q)@```!;74%<05W#9I`/MD,4A,`/A"'___\\
M+@^%-____X![%0`/A`____]FD.DF____#Q\`Z,/^__\/'P#KCF9F9F9F+@\?
MA```````55-(@^P(BST4E"``Z*_?__^+/0F4(`!(BX!@`@``2(MH".B9W___
MBSWSDR``#[:8Q`0``.B'W___2(M`"(/C?P^W0"#!X`<)V&:)10*+/<V3(`#H
M:-___XL]PI,@`$B+@&`"``!(BU@(Z%+?__\QTKYC6T``2(G'Z#/?__^+/9V3
M(`!(B4,HZ#3?__^+/8Z3(`!(BX!@`@``2(M8".@>W___2(N`@`8``(L]<9,@
M`$B)0S#H"-___XL]8I,@`$B+@&`"``!(BU@(Z/+>__\QTDB#N/@)````=!F+
M/4"3(`#HV][__TB+@/@)``!(BY"H````BSTGDR``2(E3..B^WO__2(N`8`(`
M`(L]$9,@`$B+0`A(QT!``````.B@WO__2(N`8`(``(L]\Y(@`$B+0`A(QT`@
M`````.B"WO__BSW<DB``2(N`8`(``$B+6`CH;-[__TB+@'`"``!(B4-(2(/$
M"%M=PV8N#Q^$``````!32(G[BSVFDB``Z$'>__](C9"8````2(G>OP$```#H
M?=___X7`=`DQP%O##Q]$``"+/7J2(`#H%=[__XN`L````"4`\```/0!```!T
M'8L]79(@`.CXW?__BX"P````)0#P```]`*```'6]2(G?O@(```#HV=[__X7`
M#Y3`#[;`6\-F9F9F9F8N#Q^$``````!!5+K_#P``28GT54B)_;^*64``4TB!
M[!`0``!(B>9D2(L$)2@```!(B80D"!```#'`Z%K;__^%P'YNC4C_2&/9@#P<
M`'1:2&/82(G:OB\```!(B>?HQ]S__TB%P'1*BSV\D2``Z%?=__](B=E(B>)(
MB>Y(B<?H9M[__TB+A"0($```9$@S!"4H````=39(@<00$```6UU!7,,/'X``
M````A<EUI0\?0`"+/7*1(`#H#=W__TR)XDB)[DB)Q^B_V___Z[?H>-O__P\?
MA```````2(/L"(L]1I$@`.CAW/__N9E90`"Z`!Q``+ZC64``2(G'2(/$".GV
MW/__9@\?1```2(/L"(L]%I$@`.BQW/__2(G'Z+G___^+/0.1(`#HGMS__T&X
M8UM``$4QR;H@5$``3(G!OK]90`!(B<=(@\0(Z0S=__]F9F8N#Q^$``````!3
M2('L("```&1(BP0E*````$B)A"08(```,<#H0-K__T&YE5E``$&)P+G464``
M,<"Z`1```+X!````2(GGZ-[=__^%P'AJ2(VT)!`0``"Z`!```$B)Y^CEV?__
MA<!(B<-X3HUX`4AC_^@3W/__2(7`=#Y(8]M(C;0D$!```$B)QTB)VNBXV___
MQ@08`$B+E"08(```9$@S%"4H````=15(@<0@(```6\,/'X0``````#'`Z]CH
M-]K__P\?@`````#I.____V9F+@\?A```````055!5$F)_+_B64``55-(B?-(
M@>PX$```9$B+!"4H````2(F$)"@0```QP$B-="0<Z"OW__^^+P```$R)YTB)
MQ>C[V?__2(7`=#=,B>:_ZUE``#'`Z"?X__],B>!(B[0D*!```&1(,S0E*```
M``^%.P$``$B!Q#@0``!;74%<05W#3(GGZ(?9__](B=^^^%E``$&)Q>@7W/__
M2(G##Q]``$B%VW2E@#L`N.!90`!(#T382(7M=!-(B=Y(B>_H;]K__X7`#X2@
M````2(G?Z#_9__^)P4B82(U4`_^`.B]U$)#&`@!(@^H!@^D!@#HO=/%!C40-
M`3W_#P``#X]+____2(U\)"!!N?I90`!)B=BY&5M``+H`$```O@$````QP$R)
M)"3H*=S__XL]TXX@`.ANVO__2(UT)"!(C9"8````OP$```#H:-C__X7`=1V+
M/:Z.(`#H2=K__XN`L````"4`\```/0"```!T%+[X64``,?_H.]O__TB)P^DC
M____2(U\)""^`0```.@4V___A<!UV4B-="0@O^M90`#HX?;__TB-?"0@Z#?9
M___IKO[__^AMV/__9F9F9BX/'X0```````^V#TB)^(3)=!A(C5<!9I"`^2\/
MM@I(#T3"2(/"`83)=>[SPV9F9BX/'X0``````$B%_U-(B?MT+X`_`'0JZ`W8
M__](C50#_T@YTW(,ZT>02(/J`4@YVG0'@#HO=/+K+8`Z+W5_#Q\`OP(```#H
M?MG__TB%P'1INBX```!FB1!;PP\?@`````"`.B]T"4B#Z@%(.=-R\D@YVG4*
MZ\,/'P"`.B]U"4B#Z@%(.=-R\D@IVDB-0@)(/0`0``!W(TB)WDB#P@&Y`!``
M`+_`TF``Z'W9__^XP-)@`%O#9@\?1```,<!;PUN_^EE``.DQV/__D$B#[$B_
M_%E``&1(BP0E*````$B)1"0X,<!(BP5`%@``2(E$)!!(BP4\%@``2(E$)!A(
MBP4X%@``2(E$)"!(BP4T%@``2(E$)"@/MP4P%@``9HE$)#`QP.@4]?__,<"_
M!5I``.@(]?__,<"_#5I``.C\]/__,<"_%EI``.CP]/__,<"_'5I``.CD]/__
M,<"_+5I``.C8]/__,<"_XEE``.C,]/__,<"_.5I``.C`]/__,<"_0UI``.BT
M]/__,<"_35I``.BH]/__,<"_ZUE``.B<]/__,<"_5UI``.B0]/__,<"_8%I`
M`.B$]/__2(UT)`PQP+]K6D``Z+/S__](A<!T#TB)QK]#6D``,<#HO_3__TB-
M="0,,<"_?%I``.B.\___2(7`=`](B<:_CEI``#'`Z)KT__](C70D##'`OYE:
M0`#H:?/__TB%P'0\2(G&O^)90``QP.AU]/__,<"^Q5I``+\=6D``Z&3T__](
MBT0D.&1(,P0E*````'5:2(/$2,,/'X``````2(UT)`PQP+^I6D``Z!?S__](
MA<!T$DB)QK\Y6D``,<#H(_3__^NLD$B-="0AO[I:0`"Y"@```/.F=9A(C70D
M*[\Y6D``,<#H_//__^N%Z)75__\/'T0``(L%4HL@`(/X_W0%PP\?0`!(@^P8
M,<"_.5I``$B-="0,Z*OR__](A<!T)@^V$#'`A-)T"#'`@/HP#Y7`B047BR``
M2(/$&,-F+@\?A```````,<#KYV9F9BX/'X0``````$B#[`CH-]7__XG'Z.#4
M__](A<!T"TB+`$B#Q`C##Q\`,<#K]&9F9BX/'X0``````$%7059)B?Y!54&]
MT5I``$%45;W'6D``4TB#[&A(QT0D(-%:0`!(QT0D*,=:0`!,C60D,$C'1"0P
MU%I``$C'1"0XREI``$C'1"1`SUI``$C'1"1(X5I``$C'1"10`````.LF9@\?
M1```2(G'Z+#7__](A<!T4TB%[70\28L$)$F)[4F#Q`A(B<5(C70D'#'`3(GO
MZ*GQ__](A<!(B<-,B?9T!8`X`'7!3(GO,<#HK_+__TB%[77$2(/$:%M=05Q!
M74%>05_##Q\`3(GWZ"#4__](B=])B<?H%=3__TF-?`<"Z*O5__](B1PD28G'
M2(G'0;GX64``38GPN1E;0`!(Q\+_____O@$````QP.@@U___3(G^3(GO,<#H
M0_+__^N2D$%7059!54%428G\O^)90`!54TB![)B!``!D2(L$)2@```!(B80D
MB($``#'`2(UT)#Q(QT0D0/A:0`!(QT0D2.!90`!(QT0D4`````!(QX0D@```
M`(Y:0`!(QX0DB````(=:0`!(QX0DD````/U:0`!(QX0DF````*1:0`!(QX0D
MH`````5;0`!(QX0DJ`````````!(QT0D8.Q:0`!(QT0D:`E;0`!(QT0D<```
M``#H;/#__TB%P'0)@#@`#X5&!```,<#HY_W__TB%P$B)PP^$4@0``$B)W^CS
MTO__2(U\``'HB=3__X`[`$F)Q4B)Q70R9@\?1```1`^V`TB)[S'`N1);0`!(
MQ\+_____O@$```!(@\,!2(/%`NCQU?__@#L`==1(C:PDB````+^.6D``ZQ(/
M'T0``$B#Q0A(BWWX2(7_=#M(C70D/#'`Z,_O__](A<!(B<-TWX`X`'3:2(G'
MZ*KU__^%P'3.2(G?Z"[3__](A<!(B<-U7V8/'T0``$B+7"1`2(7;#X1:`0``
M@#L`O0$```!U)>E+`0``#Q\`2&/%2(M<Q$!(A=L/A#<!``"#Q0&`.P`/A"L!
M``!(B=_H2_7__X7`=-=(B=_HS]+__TB%P$B)PW3'2(G?Z._1__],B>F+,4B#
MP02-EO_^_O[WUB'R@>*`@("`=.B)UL'N$/?"@(````]$UDB-<0)(#T3.`-)(
M@]D#3"GI1(VT"`0$``!-8_9,B??H0M/__T&Y^EE``$B)QTB)Q4F)V+D76T``
M2,?"_____[X!````,<!,B6PD"$C'!"0@6T``Z*[4__^^P`$``$B)[^BQT/__
M@_C_='R+/4:'(`#HX=+__TB-D)@```!(B>Z_`0```.@=U/__A<`/A(T```!)
MBPPD2(L]4H<@`$F)Z+K86T``O@$````QP.@FU/__,<!(BY0DB($``&1(,Q0E
M*`````^%G0@``$B!Q)B!``!;74%<05U!7D%?PP\?`#';Z>K^__^0Z/O/__]$
MBPA!@_D1#X1R____28L,)$B+/>N&(`!)B>BZF%M``+X!````,<#HO]/__S'`
MZY</'P"+/9*&(`#H+=+__XN`L````"4`\```/0!````/A5+___^+/7&&(`#H
M#-+__XN8M````.B1T/__.<,/A33___^+/5.&(`#H[M'__XN`L````"7_`0``
M/<`!```/A1/___],B??HX-'__TB-="0\O\I:0`!(B<,QP.A\[?__2(7`2(G'
M#X3%!P``Z.O0__])BSPD2(G&Z/_U__](A<!)B<4/A*@'``!,B>_H^\___X/X
M`WXV2&/0OR5;0`"Y!0```$F-=!7\\Z9U((/X!`^$>@8``(/H!$B808!\!?\O
M#X1I!@``9@\?1```,<#H.?K__X7`=18Q]DR)[^CKT?__A<")1"0@#X5/`0``
MOL5:0`"_.5I``#'`Z/[M___H"<___TC'1"0(8UM``(D$)$&Y^EE``$F)Z+D^
M6T``2,?"_____[X!````2(G?,<#HF=+__T4QY.M,#Q]``.AKSO__@S@1=5!!
M@\0!Z+W.__](QT0D$&-;0`")!"1!N?I90`!$B60D"$F)Z+E,6T``2,?"____
M_[X!````2(G?,<#H2-+__[[``0``2(G?Z$O.__^#^/]TIDB)[^C^S?__2(G>
MO^)90``QP.A/[?__2(G?Z.?Y__](B=CIN_W__P\?@`````!(B<=(B40D(.C+
M^?__2(M$)"!(B<?H?L___^F5_?__O^Q:0`"]`0```.L5#Q]$``!(8\6#Q0%(
MBWS$8$B%_W0K2(UT)#PQP.C,Z___2(7`=-^`.`!TVDB)Q^@ZS___2(7`2(G#
M=,KI8OO__T"W#;OQ6D``Z6+[__^Z`@```$C'QN[___^)QT&)QN@ZT?__2(VT
M)(`!``"Z!@```$2)]^@ES___@+PD@`$```!U#H"\)($!``!##X0M!0``BWPD
M(#'2,?;H`-'__[B)J\WO2,>$)``!```!(T5G2,>$)!@!``!V5#(02(F$)`@!
M``"X_MRZF$C'A"0H`0```````$B)A"00`0``N/#ATL-(QX0D,`$```````!(
MB80D(`$``$B-A"0X`0``QX0D>`$```````!(B40D*)"+?"0@2(VT)(`!``"Z
M`(```.AZSO__A<!)B<=!B<0/CID!``!(B[0D*`$``$ECQXT4QD@YUDB+M"0P
M`0``=@1(@\8!2,'H'4B)E"0H`0``2`'P2(F$)#`!``!(8X0D>`$``(7`#X1&
M`0``ND````!(C;P$.`$``$B-M"2``0``*<)!.==!#T[73&/J08G43(GJZ%K.
M__^+A"1X`0``1`'@@_A`B80D>`$```^%4/___T2)^$B-O"0``0``1"G@08G$
M2(V$)(`!``!)`<7H']/__P\?@`````!!@_P_#XZE````18GF38GO#Q^$````
M``!)BP](C;PD``$``$&#[D!)@\=`2(F,)#@!``!)BT_(2(F,)$`!``!)BT_0
M2(F,)$@!``!)BT_82(F,)%`!``!)BT_@2(F,)%@!``!)BT_H2(F,)&`!``!)
MBT_P2(F,)&@!``!)BT_X2(F,)'`!``#HC-+__T&#_C]_AD&#[$!$B>+!Z@:)
MT,'B!DB#P`%!*=1(P>`&20'%2(M\)"A)8]2Y2````$R)[N@TS?__1(FD)'@!
M``#I5_[__P\?@`````!,C:PD@`$``.D;____BWPD(.A:S/__3(ND)"@!``!,
MBZPD,`$``$R)X$C!Z`.#X#^-2`%(8]#&A!0X`0``@(/Y.`^/=@(``+HW````
M2&/),?8IPDB-O`PX`0``2&/2Z-W+__],B>A(C;PD``$``$2(K"1S`0``2,'H
M&$2(I"1W`0``3(V\)-````"(A"1P`0``3(GH2,'H$$V-=RB(A"1Q`0``3(GH
M3(VL)+$```!(P>@(B(0D<@$``$R)X$C!Z!B(A"1T`0``3(G@2,'H$(B$)'4!
M``!,B>!-B?Q(P>@(B(0D=@$``.A5T?__2(N$)``!``!(B<*(A"2S````2,'J
M&$0/ML*(E"2P````2(G"2,'J$(B4)+$```!(B<)(BX0D"`$``$C!Z@B(E"2R
M````2(G"B(0DMP```$C!ZAB(E"2T````2(G"2,'J$(B4)+4```!(B<)(BX0D
M$`$``$C!Z@B(E"2V````2(G"B(0DNP```$C!ZAB(E"2X````2(G"2,'J$(B4
M)+D```!(B<)(BX0D&`$``$C!Z@B(E"2Z````2(G"B(0DOP```$C!ZAB(E"2\
M````2(G"2,'J$(B4)+T```!(B<)(BX0D(`$``$C!Z@B(E"2^````2(G"B(0D
MPP```$C!ZAB(E"3`````2(G"2,'J$(B4),$```!(B<)(P>H(B)0DP@```.D0
M````#Q^``````$4/MD4`28/%`4R)YS'`N1);0`!(Q\+_____O@$```!)@\0"
MZ.#,__]-.?1UT\:$)/@`````2,=$)`AC6T``3(D\)$&Y^EE``$F)Z+DO6T``
M2,?"_____[X!````2(G?,<#HHLS__^EG^O__38MD)`A-A>0/A(_Y__],B>?H
M1\G__TB#^`,/AGWY__])C70$_+\J6T``N04```#SIDT/1.SI8_G__TACR;H_
M````,?9(C;P,.`$``"G"2&/2Z&?)__](C;PD``$``.A:S___2(V4)#@!``"Y
M!P```#'`2(G7\TBKZ6/]__^`O"2"`0``00^%Q?K__X"\)(,!``!##X6W^O__
M@+PDA`$``$@/A:GZ__^`O"2%`0``10^%F_K__T2+="0@N@(```!(Q\;&____
M1(GWZ(_+__](C;0D@`$``+HI````1(GWZ'K)__](C80D@`$``$C'1"0(8UM`
M`$B)!"3IVO[__^AKR/__38LL).E/^/__9I!!54%455-(@^P8BSTP?B``Z,O)
M__](C70D#,:`Q00```&_'5I``#'`Z'/E__](A<!T"8`X,0^$A0(``#'`Z*[P
M__^+/?A](`#HD\G__[D+````N@$```"^75M``$B)Q^@<R?__2(7`#X2T````
M@ST\CB```4B+0!!,BV@H#XZ?````O0@````QV^LR#Q]$``!)BW0D$$B+!0R.
M(`!(BSPHZ,O(__^%P'5G@\,!BP7^C2``2(/%"(U3`3G"?5F+/7U](`#H&,G_
M_S')B=I,B>Y(B<?HZ<G__TB%P'0T3(L@0?9$)`T$=:F+/5-](`#H[LC__TR)
MYKD"````,=)(B<?HO,?__TB)QNN,#Q^``````(L%FHT@`(U0_SG:#X0_`0``
MBST9?2``Z+3(__^Y!````+H!````OF);0`!(B<?H/<C__TB%P$B)PW0S2(M`
M$(L]ZWP@`$B+*.B#R/__NF1;0`!(B<=(B>[H,\?__TB+0Q!(BQCV0PY`#X4B
M`0``BSV\?"``Z%?(__^Y!````+H!````OFE:0`!(B<?HX,?__TB%P$B)Q70]
M2(UT)`PQP+_K64``Z.?C__](A<!(B<,/A(,!``!(BT40BSUQ?"``3(L@Z`G(
M__](B=I(B<=,B>;HN\;__XL]57P@`.CPQ___BSU*?"``QH#%!````.C>Q___
M2(UT)`Q(QX!(!P```````+_B64``,<#H@N/__TB%P$B)PTB)!8V,(``/A*<`
M``"^P`$``$B)Q^ABQ?__@_@1=`R-4`&#^@$/AWD!``!(@\086UU!7$%=PV8/
M'T0``(/X`0^.N/[__[L!````9I"+/<I[(`"#PP'H8L?__TR)[DB)Q^@WQ?__
M.1TAC"``?]_IB_[__V8N#Q^$``````"+/9I[(`#H-<?__TB)WDB)Q^B*Q___
MZ</^__\/'T0``(!X`0`/A'C]__]F#Q]$``#I9OW__P\?`$B+/<F+(`#HG/'_
M_TB%P$B)!<J+(``/A,H```!(BT403(LEJ8L@`$B+&/9##01T;$B+>Q!,B>;H
M_,?__T&)Q$B+11!(BQCV0PT$='5(BU,02(L%>8L@`$2)X;]87$``2(LP,<#H
MO\;__P\?@`````!(BP59BR``BSWK>B``3(L@2(M%$$B+&.A\QO__3(GF2(G?
MZ+'H___I<?[__XL]QGH@`.AAQO__N0(```!(B<<QTDB)WN@OQ?__2(G'Z7/_
M__^+/:%Z(`#H/,;__S'2N0(```!(B=Y(B<?H"L7__TB)PNEJ____OS!<0`#H
M.,;__XG!2(L%UXH@`$B)VK^`7$``2(LP,<#H'<;__V9F9F8N#Q^$``````!5
M2(G]4TB#[`CH,NS__P^V"$B)PX3)=!I(C5`!#Q]``(#Y+P^V"D@/1-I(@\(!
MA,EU[C'`Z*?N__^%P'0=2(7M=!B`?0``=!*^(%M``$B)W^@[Q___2#G8=`=(
M@\0(6UW#2(/$"$B)[UM=Z7'D__^02(/L"(L]UGD@`.AQQ?__OO____](B<?H
MA,3__XL]OGD@`.A9Q?__,=*^0#Y``$B)QTB#Q`CIUL;__V8/'T0``$B-!7EY
M(`!(A<!T#$B+#6UY(`#I6,3__S')Z_</'T``2(EL)-A,B60DX$B-+0=U(`!,
MC27X="``2(E<)-!,B6PDZ$R)="3P3(E\)/A(@^PX3"GE08G_28GV2,']`TF)
MU3';Z"'"__](A>UT&@\?0`!,B>I,B?9$B?]!_Q3<2(/#`4@YZW7J2(M<)`A(
MBVPD$$R+9"083(ML)"!,BW0D*$R+?"0P2(/$.,,/'X``````\\-FD$B#[`A(
M@\0(PP````$``@`E<R\E<P`O<')O8R]S96QF+V5X90!P97)L>'-I+F,`1'EN
M84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4
M`"]P<F]C+R5I+R5S`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),
M-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`
M4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%2
M7T%21T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?
M5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X`4$%27T-,14%./0`Q`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`
M4TA,24)?4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).
M04U%`"4P,G@`)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S
M)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L
M`"UE`"TM``!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO
M=7(@;W!E<F%T:6]N*0H```````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0``````````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@*&5R
M<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````",A+W5S<B]B
M:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB
M)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@
M;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E
M('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE
M+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@
M(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA
M;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H
M<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z
M.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN
M:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$
M;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E
M('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A
M<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@
M=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I
M8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI
M;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B
M;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD
M"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@
M;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG
M="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P
M<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T
M:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*
M("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@
M("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@
M("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)
M3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B
M:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F
M("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE
M;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@
M("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@
M;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@
M)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D[
M"B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL
M96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@
M("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[
M4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'
M5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!
M4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@
M>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD
M7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.
M5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O
M;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^
M("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G
M)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T
M96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN
M9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P
M;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@
M("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO
M;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@
M("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@
M+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S
M("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#([
M"B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U
M;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*
M("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@
M("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@
M;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@
M>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN
M86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D
M9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE
M(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@
M("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@
M("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I
M(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U
M="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@
M("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E
M("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@
M("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL
M:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@
M("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@
M("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E
M>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*
M("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D
M:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@
M('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@
M("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI
M<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^
M("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@
M("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@
M("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@
M?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@
M(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?
M;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L
M95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME
M>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@
M("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D
M=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE
M9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[
M8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@
M("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I
M;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@
M("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I
M;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO
M<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F
M:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H
M)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@
M("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M
M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@
M8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B
M:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q
M=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@
M(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG
M(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&
M:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?
M7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD
M9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@
M("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F
M:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3
M:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@
M("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@
M('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@
M?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*9&5L
M971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA
M>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R
M(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII
M9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS
M)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@
M('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@
M("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@
M("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@(R!I9B!T:&4@87!P
M(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M;W!T:6]N<R`M+7)E=7-E
M(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C('5S92!T:&4@87!P('1O(')U
M;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@;V8@86YY=&AI;F<@9G)O
M;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T:6QL('-E="!U<"!T:&4@
M;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.0RD*("`@(&EF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["B`@("`@("`@<VAI9G0@
M0$%21U8["B`@("`@("`@)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R
M"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@("`@('=H:6QE("A`05)'
M5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU
M<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@("`@:68@*"0Q(&5Q("=)
M)RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@
M("`@("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@("`@("`@("`@("`@
M("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@("`@("`@)&]U
M="`]("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E
M<2`G8B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=")RD@>PH@
M("`@("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@
M("`@("1Q=6EE="`](#$["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@("`@;W!E;B`D;&]G9F@L
M("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)U0G*2![
M"B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!S:&EF="A`05)'5BD["@H@("`@("`@("`@("!I
M9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@("`@
M(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@("`@("`@("`@:6YI
M=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@
M("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@97AI=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O
M<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII
M9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG
M?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q
M=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*
M("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II
M<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@
M)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A
M(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A
M<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@
M9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E
M96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z
M:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@("`@("`@("1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<
M4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N
M*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N
M9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF
M("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R
M(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@
M("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2
M/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T
M*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@
M)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z
M.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W
M-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D
M+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968[
M"B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@
M/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E
M<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@
M/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A
M;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?
M14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@
M/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@("`@("`@)&QO861E
M<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T
M("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@
M("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@
M/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L
M97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2
M.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U
M;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@
M;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@
M("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@
M("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@
M("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@
M?2!`24Y#.PH*("`@("`@("`C($9I;&4@97AI<W1S('1E<W0@861D960@=&\@
M9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@
M96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L
M:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@
M;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*("`@("`@("`C(%-O;65B
M;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P86EN(&]F('5N9&5R<W1A;F1I
M;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C($D@9F%I;&5D+B`M+2!3
M=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@
M86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@
M("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY
M("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@
M(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I
M;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@
M("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@
M("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@
M("`@("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@
M("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@
M("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@
M("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<
M6B$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@
M;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R
M968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@
M("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A
M8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*
M("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@
M("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL
M92DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E
M;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*
M("`@("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@
M("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@
M("`@("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D
M;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE+"`D;F%M92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F
M:"T^<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP
M<FEN="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H
M:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@
M("`@("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O
M;G1E;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@
M=W)I=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D
M>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A
M8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@
M*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=
M*2!["B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]
M"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$
M:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@
M8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D
M<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@
M?'P@,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D
M<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D
M9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L
M("(\)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@
M("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@
M("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D
M;71I;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@
M;&5N9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(
M12(["B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@
M("`@)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*
M("`@(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*
M(R!]?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H
M92![>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*
M("`@(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@
M9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E
M<75I<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PH*"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&
M24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I
M;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]
M"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L
M("1Z:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*
M"B`@("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<
M)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T
M('1H:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II
M<"T^;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE
M;6)E<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB
M97)?;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@
M("`@+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I
M9WMV97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@
M("`@("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@
M)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US
M(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@
M("`@("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E
M(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@
M("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA
M;64I.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@
M:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L
M('1O(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H
M97LD<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*
M57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@
M72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM
M8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*
M"G-U8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@
M("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L
M("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA
M;64L("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@
M("`@"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D
M<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER
M95]M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,
M15]?(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@
M("!R97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@
M("!R97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R
M97%U:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A
M<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I
M<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E
M($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER
M92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E
M($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E
M<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U
M:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PH@("`@<F5Q=6ER92!A='1R:6)U=&5S
M.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T[
M"B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T[
M"B`@("!E=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A<'!E
M87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E
M<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS=6(@
M7W-E=%]P87)?=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!A
M<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A
M8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!005)?
M5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@('%W
M*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PH@
M("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@("`@
M("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A;"![
M*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*("`@
M("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@("`@
M("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@
M("!]"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@("`@
M("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@96QS
M92!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\
M("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@("1U
M<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B
M)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N
M86UE*3L*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I
M9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R
M;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@
M("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@
M("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E
M96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@
M)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@
M("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C
M:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@
M("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T
M.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@
M("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI3
M2$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S
M:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@
M("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D
M<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@
M)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G
M;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@
M)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@
M("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0[
M"B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL
M92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F
M:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X
M="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN
M:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M
M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E
M='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@
M("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*
M("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D[
M"GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ
M<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD969I
M;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345]
M(#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*
M("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@
M(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@
M+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N
M9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@
M?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T
M<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*
M("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@
M("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@
M("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M
M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345]
M.PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\
M(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$
M('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I
M;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@
M8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#
M;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN
M:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@
M,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%
M3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@
M05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*
M("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@
M?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@
M("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H
M(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@
M)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!
M3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@
M/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@
M("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@
M('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@
M("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R
M97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M
M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X
M<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R
M:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N
M<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R
M7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@
M("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]2
M13HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L
M:6YE(#$P,3$*"E]?14Y$7U\*````````````````````P$,!&P,[]````!T`
M``#H8O__0`$``#AG___H!0``4&G__Q`!``!(:O__:`$``#B!__^X`0``^('_
M_Q@"``!8@O__.`(``&B$__^(`@``N(7__]@"```HA___"`,``+B'__\H`P``
MB(C__V`#``"XB/__>`,```B)__^0`P``R(G__[@#``#8B?__T`,``)B+__\0
M!```R(O__R@$``"(C/__6`0``&B.__]X!```R([__Y@$``#XCO__N`0``!B0
M__\(!0``F)O__U@%``"(G___F`4``/B?___0!0``.*#__Q`&``!8H/__*`8`
M`.B@__]0!@```````!0``````````7I2``%X$`$;#`<(D`$'$!0````<````
M.&C__RH``````````````!0``````````7I2``%X$`$;#`<(D`$``"0````<
M````H&'__U`$````#A!&#AA*#PMW"(``/QH[*C,D(@````!,````1````-AH
M___I%@```$(.$(\"2`X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.R`0#QQ8.
M.$$.,$$.*$(.($(.&$(.$$(."````````%P```"4````>'___[8`````0@X0
MCP)"#AB.`T(.((T$10XHC`5!#C"&!D$..(,'1`Y``G$*#CA##C!!#BA"#B!"
M#AA"#A!"#@A""UL..$$.,$$.*$(.($(.&$(.$$(."!P```#T````V'___U@`
M````00X0@P)'#B`"3@X000X(3````!0!```8@/__#0(```!"#A"/`D0.&(X#
M0@X@C01"#BB,!40.,(8&00XX@P='#E`#``$*#CA!#C!!#BA"#B!"#AA"#A!"
M#@A("P````!,````9`$``-B!__]"`0```$(.$(T"0@X8C`-!#B"&!$0.*(,%
M1P[``5$*#BA!#B!!#AA"#A!"#@A)"P+7"@XH00X@00X80@X00@X(0PL``"P`
M``"T`0``V(+__V8!````00X0A@)!#AB#`T0.(`-=`0X800X000X(````````
M`!P```#D`0``&(3__X$`````00X0@P)I"@X(1@L"4`X(-`````0"``"(A/__
MR`````!"#A",`DD.&(8#20X@@P1'#K`@`GD*#B!!#AA!#A!"#@A("P`````4
M````/`(``""%__\J`````$0.$&$."``4````5`(``#B%__]$`````$0.$'L.
M"``D````;`(``'"%__^Y`````$$.$(,"1PZP0`*>"@X000X(20L`````%```
M`)0"```(AO__!0``````````````/````*P"````AO__LP$```!"#A"-`D(.
M&(P#20X@A@1!#BB#!4H.X"`"8@H.*$$.($$.&$(.$$(."$$+`````!0```#L
M`@``@(?__R0``````````````"P````$`P``F(?__[\`````1`X0@P("3`H.
M"$@+`E$*#@A'"T,*#@A!"T$."````!P````T`P``*(C__]L!````1`Y0`WP!
M"@X(2`L`````'````%0#``#HB?__5`````!4#B!Q"@X(2PL````````<````
M=`,``"B*__\D`````$0.$%@*#@A$"P```````$P```"4`P``.(K__Q\!````
M0@X0CP)"#AB.`T4.((T$2`XHC`5!#C"&!D8..(,'1`Z@`0*>"@XX00XP00XH
M0@X@0@X80@X00@X(1`L`````3````.0#```(B___?@L```!"#A"/`D(.&(X#
M0@X@C01"#BB,!4D.,(8&00XX@P='#M"#`@/!`@H..$$.,$$.*$(.($(.&$(.
M$$(."$0+```\````-`0``#B6___C`P```$(.$(T"0@X8C`-!#B"&!$$.*(,%
M1`Y``TD""@XH00X@00X80@X00@X(1PL`````-````'0$``#HF?__;P````!!
M#A"&`D0.&(,#1`X@`E4*#AA!#A!!#@A!"T0.&$0.$$$."``````4````K`0`
M`"":__\Z`````$0.$'$."``D````Q`0``$AA__\8`@```$$.$(,"1`Y``Y0!
M"@X00PX(00L`````%````.P$```@FO__'```````````````)`````0%```H
MFO__B0````!*A@:,!68.0(,'C02.`X\"`E@."````!0````L!0``D)K__P(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````*`B0```````@")`````````````
M``````$``````````0`````````!``````````4"`````````0````````!4
M`@````````P`````````2!M````````-`````````'190```````&0``````
M``#PS6```````!L`````````"``````````:`````````/C-8```````'```
M```````(`````````/7^_V\`````F`)````````%`````````.`-0```````
M!@````````#P`T````````H`````````(`4````````+`````````!@`````
M````%0````````````````````,``````````-!@```````"`````````&`&
M````````%``````````'`````````!<`````````Z!1````````'````````
M`%@40```````"`````````"0``````````D`````````&`````````#^__]O
M`````-@30```````____;P`````"`````````/#__V\``````!-`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````C.8````````````````````````````(8;0```````
MEAM```````"F&T```````+8;0```````QAM```````#6&T```````.8;0```
M````]AM````````&'$```````!8<0```````)AQ````````V'$```````$8<
M0```````5AQ```````!F'$```````'8<0```````AAQ```````"6'$``````
M`*8<0```````MAQ```````#&'$```````-8<0```````YAQ```````#V'$``
M``````8=0```````%AU````````F'4```````#8=0```````1AU```````!6
M'4```````&8=0```````=AU```````"&'4```````)8=0```````IAU`````
M``"V'4```````,8=0```````UAU```````#F'4```````/8=0```````!AY`
M```````6'D```````"8>0```````-AY```````!&'D```````%8>0```````
M9AY```````!V'D```````(8>0```````EAY```````"F'D```````+8>0```
M````QAY```````#6'D```````.8>0```````]AY````````&'T```````!8?
M0```````)A]````````V'T```````$8?0```````5A]```````!F'T``````
M`'8?0```````AA]```````"6'T```````*8?0```````MA]`````````````
M````````````````_____P````#(7$```````$=#0SH@*%5B=6YT=2`T+C@N
M,"TW=6)U;G1U,2D@-"XX+C``1T-#.B`H56)U;G1U+TQI;F%R;R`T+C<N,RTQ
M=6)U;G1U,2D@-"XW+C,``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT
M86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L
M82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA
M;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````
M````````````````````````````````````````````````````````````
M````````````````````"P````$````"`````````#@"0```````.`(`````
M```<`````````````````````0```````````````````!,````'`````@``
M``````!4`D```````%0"````````(`````````````````````0`````````
M```````````A````!P````(`````````=`)```````!T`@```````"0`````
M```````````````$````````````````````-````/;__V\"`````````)@"
M0```````F`(```````!8`0````````4`````````"```````````````````
M`#X````+`````@````````#P`T```````/`#````````\`D````````&````
M`0````@`````````&`````````!&`````P````(`````````X`U```````#@
M#0```````"`%```````````````````!````````````````````3@```/__
M_V\"```````````30````````!,```````#4``````````4``````````@``
M```````"`````````%L```#^__]O`@````````#8$T```````-@3````````
M@``````````&`````@````@```````````````````!J````!`````(`````
M````6!1```````!8%````````)``````````!0`````````(`````````!@`
M````````=`````0````"`````````.@40```````Z!0```````!@!@``````
M``4````,````"``````````8`````````'X````!````!@````````!(&T``
M`````$@;````````&@````````````````````0```````````````````!Y
M`````0````8`````````<!M```````!P&P```````%`$````````````````
M```0`````````!``````````A`````$````&`````````,`?0```````P!\`
M``````"T.0``````````````````$````````````````````(H````!````
M!@````````!T64```````'19````````"0````````````````````0`````
M``````````````"0`````0````(`````````@%E```````"`60````````A?
M```````````````````(````````````````````F`````$````"````````
M`(BX0```````B+@```````#T````````````````````!```````````````
M`````*8````!`````@````````"`N4```````("Y````````=`4`````````
M``````````@```````````````````"P````#@````,`````````\,U@````
M``#PS0````````@````````````````````(````````````````````O```
M``\````#`````````/C-8```````^,T````````(````````````````````
M"````````````````````,@````!`````P``````````SF````````#.````
M````"`````````````````````@```````````````````#-````!@````,`
M````````",Y@```````(S@```````/`!````````!@`````````(````````
M`!``````````U@````$````#`````````/C/8```````^,\````````(````
M````````````````"``````````(`````````-L````!`````P``````````
MT&````````#0````````.`(```````````````````@`````````"```````
M``#D`````0````,`````````.-)@```````XT@```````"``````````````
M```````(````````````````````Z@````@````#`````````&#28```````
M6-(```````"($```````````````````(````````````````````.\````!
M````,````````````````````%C2````````30````````````````````$`
M`````````0`````````!`````P````````````````````````"ET@``````
A`/@````````````````````!````````````````````
